@@ -4,6 +4,8 @@ from .blocks import *
 
 from .commons import *
 
+from .secrets import moose_runtime_env
+
 from .data_models import *
 
 from .dmv2 import *
@@ -19,6 +21,10 @@ from .blocks import (
     ReplacingMergeTreeEngine, 
     AggregatingMergeTreeEngine,
     SummingMergeTreeEngine,
+    ReplicatedMergeTreeEngine,
+    ReplicatedReplacingMergeTreeEngine,
+    ReplicatedAggregatingMergeTreeEngine,
+    ReplicatedSummingMergeTreeEngine,
     S3QueueEngine,
     EngineConfig,
     # Legacy enum (already exported via .blocks import, but explicit for clarity)
